var APIBase = require("../../api.base");
var system = require("../../../system");
var settings = require("../../../../config/settings");
class ActionAPI extends APIBase {
    constructor() {
        super();
        this.cclueSve = system.getObject("service.chance.cclueSve");
        this.cfollowlogSve = system.getObject("service.chance.cfollowlogSve");
        this.cschemeSve = system.getObject("service.chance.cschemeSve");
    }
    /**
     * 接口跳转
     * action_process  执行的流程
     * action_type     执行的类型
     * action_body     执行的参数
     */
    async springboard(pobj, qobj, req) {
        var result;
        if (!pobj.action_process) {
            return system.getResult(null, "action_process参数不能为空");
        }
        if (!pobj.action_type) {
            return system.getResult(null, "action_type参数不能为空");
        }
        try {
            result = await this.handleRequest(pobj.action_process, pobj.action_type, pobj.action_body);    
        } catch (error) {
            console.log(error);
        }
        
        return result;
    }

    async handleRequest(action_process, action_type, action_body) {
        var opResult = null;
        switch (action_type) {
            case "saveClue"://保存线索
                opResult = await this.cclueSve.saveClue(action_body);
                break;
            case "closeClue"://关闭商机
                opResult = await this.cclueSve.closeClue(action_body);
                break;
            case "listClue"://列表商机
                opResult = await this.cclueSve.listClue(action_body);
                break;
            case "clueStatusDict"://列表商机字典
                opResult = await this.cclueSve.clueStatusDict(action_body);
                break;
            case "closeReasonDict"://关闭商机字典
                opResult = await this.cclueSve.closeReasonDict(action_body);
                break;
            case "getClueById": //根据线索ID查询详细
                opResult = await this.cclueSve.getClueById(action_body);
                break;
            case "saveCfollowLog": //保存跟进进度
                opResult = await this.cfollowlogSve.saveCfollowLog(action_body);
                break;
            case "saveCscheme": //保存方案
                opResult = await this.cschemeSve.saveCscheme(action_body);
                break;
            default:
                opResult = system.getResult(null, "action_type参数错误");
                break;
        }
        return opResult;
    }
    exam() {
        return `<pre><pre/>`;
    }
    classDesc() {
        return {
            groupName: "op",
            groupDesc: "元数据服务包",
            name: "ActionAPI",
            desc: "此类是对外提供接口服务",
            exam: "",
        };
    }
    methodDescs() {
        return [
            {
                methodDesc: `<pre><pre/>`,
                methodName: "springboard",
                paramdescs: [
                    {
                        paramDesc: "请求的行为，传递如：sjb",
                        paramName: "action_process",
                        paramType: "string",
                        defaultValue: null,
                    },
                    {
                        paramDesc: "业务操作类型，详情见方法中的描述",
                        paramName: "action_type",
                        paramType: "string",
                        defaultValue: null,
                    },
                    {
                        paramDesc: "业务操作类型的参数，action_body必须传递的参数有，times_tamp（时间戳，类型int）、sign(签名,类型string)，其余的为业务需要的参数",
                        paramName: "action_body",
                        paramType: "json",
                        defaultValue: null,
                    }
                ],
                rtnTypeDesc: `<pre><pre/>`,
                rtnType: `<pre><pre/>`
            }
        ];
    }
}
module.exports = ActionAPI;